import unittest

from jinsi.util import load_all


class UtilTest(unittest.TestCase):
    def test_load_all(self):
        x = load_all("""{}{}""")
        self.assertEqual([{}, {}], [*x])


if __name__ == '__main__':
    unittest.main()



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

__pkginfo__ = {}
with open("jinsi/__pkginfo__.py") as fh:
    exec(fh.read(), __pkginfo__)


class Info:
    version = __pkginfo__.get("version", None)


setuptools.setup(
    name="jinsi",
    version=Info.version,
    author="Julian Fleischer",
    author_email="tirednesscankill@warhog.net",
    description="JSON/YAML homoiconic templating language",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/scravy/jinsi",
    scripts=[
        "bin/jinsi"
    ],
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.7',
    install_requires=[
        'dezimal>=0.4.0',
        'pyyaml>=5.0.0',
    ],
)



import re
import sys
import textwrap

from jinsi import __pkginfo__
from jinsi import parse_yaml, parse_file, render_json, render_yaml


def print_version():
    print(f"jinsi {__pkginfo__.version}")


def print_help():
    print(textwrap.dedent(f"""
        {sys.argv[0]} [-j] [args...]
    
        ...where each argument may be:
        
          - a filename
          - a dash (to denote reading from standard input)
          - a variable binding of the form "key=value"
    
        The following options are recognized:
        
          -j  --json      Format output as JSON lines
        
        Standalone options:
    
          -v  --version   Print version information
          -h  --help      Print this help screen
        
    """))


def main():
    args = []
    env = {}
    fmt_json = False
    args_it = iter(sys.argv)
    next(args_it)
    opt_parsing = True
    for arg in args_it:
        if arg == "--":
            opt_parsing = False
            continue
        if opt_parsing:
            if arg in ("-v", "-version", "--version"):
                print_version()
                return
            if arg in ("-h", "-help", "--help"):
                print_help()
                return
            if arg in ("-j", "-json", "--json"):
                fmt_json = True
                continue
            m = re.match(r"([^=]+)=(.*)", arg)
            if m:
                key = m.group(1)
                val = m.group(2)
                env[key] = val
                continue
        args.append(arg)
    if not args:
        args = ["-"]
    for arg in args:
        if arg == '-':
            doc = parse_yaml(sys.stdin.read())
        else:
            doc = parse_file(arg)
        if fmt_json:
            print(render_json(doc, **env))
        else:
            print("---")
            print(render_yaml(doc, **env))



import unittest

from apm import *
from dezimal import *

from jinsi import *


class LoadTest(unittest.TestCase):

    def test_load(self):
        doc = load_yaml("""\
            foo: bar
            qux: quux
            """)
        self.assertTrue(match(doc, Strict(Object(
            foo='bar',
            qux='quux',
        ))))

    def test_load_dezimal(self):
        doc = load_yaml("""\
            foo: 1.34
            """, numtype=Dezimal)
        self.assertFalse(match(doc, Strict(Object(
            foo=Strict(float("1.34"))
        ))))
        self.assertTrue(match(doc, Strict(Object(
            foo=Strict(Dezimal("1.34"))
        ))))

    def test_load_float(self):
        doc = load_yaml("""\
            foo: 1.34
            """)
        self.assertFalse(match(doc, Strict(Object(
            foo=Strict(Dezimal("1.34"))
        ))))
        self.assertTrue(match(doc, Strict(Object(
            foo=Strict(float("1.34"))
        ))))
